test_module_with_large_stack():  This failed when Python was run with -O,
trying to delete a .pyc file that didn't exist (it needed to delete .pyo
then).
diff --git a/Lib/test/test_import.py b/Lib/test/test_import.py
index 9342812..1ddd13e 100644
--- a/Lib/test/test_import.py
+++ b/Lib/test/test_import.py
@@ -88,7 +88,7 @@
     f.write(']')
     f.close()
 
     # compile & remove .py file, we only need .pyc
     f = open(filename, 'r')
     py_compile.compile(filename)
     f.close()
@@ -102,6 +102,9 @@
 
     # cleanup
     del sys.path[-1]
-    os.unlink(module + '.pyc')
+    for ext in '.pyc', '.pyo':
+        fname = module + ext
+        if os.path.exists(fname):
+            os.unlink(fname)
 
 test_module_with_large_stack('longlist')
@@ -88,7 +88,7 @@
     f.close()
 
-    # compile & remove .py file, we only need .pyc
+    # compile & remove .py file, we only need .pyc (or .pyo)
     f = open(filename, 'r')
     py_compile.compile(filename)